# Lineární zobrazení

- $\mathcal{U} = R^4$ - LVP před zobrazením
- $\mathcal{V}= R^3$ - LVP po zobrazení
- $\mathbb L : \mathcal{U} \to \mathcal{V}$ 

Zobrazení $\mathbb L : \mathcal{U} \to \mathcal{V}$ kde $\mathcal{U}, \mathcal{V}$ jsou LVP, jestliže pro každé $\vec x, \vec y \in \mathcal{U}$ a pro každé $c \in \mathbb R$ platí:
1. $\mathbb{L}(\vec x + \vec y) = \mathbb{L}(\vec x) + \mathbb{L}(\vec y)$
2. $\mathbb{L}(c \cdot \vec x) = c \cdot \mathbb{L}(\vec x)$

Nazývá se také **homomorfizmus**.

$\dim(Ker \space \mathbb L) + \dim(Im \space \mathbb L) = \dim(\mathcal U)$

### Jádro

- všechny LK vektorů před zobrazením, které se po zobrazení rovnají 0
- zjištění přes zjištění LK
	- $Ker \space \mathbb{L} = \{ \forall \vec x \in \mathcal U; \mathbb L (\vec x) = 0  \}$
- zápis: $Ker \space \mathbb{L} = \langle \vec{u}; \vec{v} \rangle$

Zapíšu zobrazení do matice, po provedení GJEM zjistím, které prvky se zobrazí na nulový vektor (tedy si vyjádřím např. $a, b, c$).

### Obraz

- všechny LK vektorů po zobrazení
	- $Im \space \mathbb{L} = \{ \vec y \in \mathcal V; \exists \vec x \in \mathcal U, \mathbb{L}(\vec x) = \vec y \}$
- zápis: $Im \space \mathbb{L} = \langle \vec{u}; \vec{v} \rangle$

Vypočítám jej opět zapsáním zobrazení do matice a provedením GJEM. Obrazem je poté LN množina vektorů (podobné jako u báze).

### Lineární operátor

Lineární zobrazení $\mathbb{L} : U \to U$.

### Identické zobrazení

Zobrazení $\mathbb F$ definované vztahem $\mathbb F(x) = (x)$.

### Prosté zobrazení

Žádné dva rozdílné prvky se **nezobrazí** na jeden stejný prvek.
- $Ker \space \mathbb{L} = \{\vec{o}_{\mathcal U}\}$
- $\dim(Ker \space \mathbb{L}) = 0$

### Zobrazení na

Celý prostor $\mathcal{U}$ se zobrazuje na celý prostor $\mathcal{V}$.
- $\forall v \in \mathcal V : \exists u \in \mathcal U : f(u) = v$
- $Im(\mathbb{L}) = \mathcal{V}$

### Izomorfní zobrazení

Lineární zobrazení je **izomorfizmem**, pokud je **prosté a na**, dimenze jeho obrazu je stejná jako dimenze prostoru V.
- platí zároveň
	- $Ker \space \mathbb{L} = \{\vec{o}_{\mathcal U}\}$
	- $\dim(Im \space \mathbb{L}) = \dim(\mathcal V)$
- dimenze obou prostorů se musí rovnat, jinak se nejedná o izomorfizmus
	- $\dim(\mathcal U) = \dim(\mathcal V)$

**Vlastnosti**
- **matice $M$ lineárního zobrazení** pro izomorfní zobrazení **je regulární**
- inverzní izomorfní zobrazení $\mathbb L^{-1}:\mathcal{V} \to \mathcal{U}$ je také izomorfní
	- matice lin. zobrazení pro inverzní izomorfní zobrazení je $M^{-1}$
- prvky $\vec{x}_{1}, \vec{x}_{2}, \dots, \vec{x}_{n} \in \mathcal{U}$ jsou **LZ**, pokud $\mathbb L(\vec{x}_{1}), \mathbb L(\vec{x}_{2}), \dots, \mathbb L(\vec{x}_{n}) \in \mathcal{V}$ jsou **LZ**

### Inverzní zobrazení

Je-li $f : A \to B$ zobrazení, pak inverzním zobrazením je $f^{-1} : B \to A$.
- $f^{-1}(b) = a$
- $f(a) = b$

## Matice lineárního zobrazení

Nejsnadnější způsob, jak počítačově popsat lineární zobrazení.

Znázorňuje vztah souřadnicemi prvku vzhledem k jedné bázi a souřadnicemi zobrazení prvku vzhledem k druhé bázi.
- **Dimenze obrazu** lineárního zobrazení $\mathbb{L}$ je **stejná jako hodnost matice** lineárního zobrazení.
- Pokud je matice lineárního zobrazení **regulání**, lineární zobrazení je **izomorfizmus**.

**Postup**:
- Určete matici zobrazení $\mathbb{L}$ v bázích $B_{1}$ a $B_{2}$.
1. Vektory první báze **zobrazím pomocí lineárního zobrazení**.
2. Zobrazené vektory napíšu do sloupců matice $A_{2}$.
3. Do matice $A_{1}$ napíšu do sloupců vektory ze druhé báze.
4. Matice **spojím** do matice $A = [A_{1} \mid A_{2}]$, kterou vyřeším pomocí GJEM.
5. Na **levé straně** díky GJEM dostanu **jednotkovou matici** a na **pravé straně** vznikne **matice lineárního zobrazení**.

### Matice přechodu

Matice identického lineárního zobrazení vzhledem k bázím $B_{1}$ a $B_{2}$.

Nechť $T$ je matice přechodu od báze $B_{2}$ k bázi $B_{1}$ (je to naopak).
- $T$ je regulární
- $T_{\vec{u}_C} = \vec{u}_D \quad \forall \vec{u} \in U$
- $T^{-1}$ je matice přechodu od báze $B_{1}$ k bázi $B_{2}$

Postup je stejný jako u matice lineárního zobrazení, jen prvky první báze nezobrazuji a rovnou je zapíšu do matice.

### Složené zobrazení

Nechť $\mathbb{L}_{1} : U \to V, \mathbb{L}_{2} : V \to W$ a báze v $U, V, W$ jsou $C, D, E$. A je matice $\mathbb L_1$ vzhledem k bázím $C, D$ a $B$ je matice $\mathbb L_{2}$ vhledem k bázím $D, E$.

Složené zobrazení $\mathbb L = \mathbb L_{2} \circ \mathbb L_{1} : U \to W$ je lineární a jeho matice vzhledem k bázím $C, E$ je rovna matici $B \cdot A$.

Důsledky:
- Pro uvedené matice lin. zobr. platí: $hod(B \cdot A) \leq \min\{hod(A), hod(B)\}$.
- Pokud je lineární zobrazení izomorfizmus s maticí $A$ vzhledem k bázím $C, D$, potom inverzní zobrazení má vzhledem k bázím $D, C$ matici $A^{-1}$.